pub struct FlowGatePrincipal {
pub id: PrincipalId,
pub authority: AuthorityLevel,
pub domains: Vec<DomainId>,
pub policy_version: Option<PolicyVersionId>,
}Expand description
Principal facts projected from the flow host or application runtime.
Fields
id: PrincipalIddomains: Vec<DomainId>policy_version: Option<PolicyVersionId>Trait Implementations
Sourceimpl Clone for FlowGatePrincipal
impl Clone for FlowGatePrincipal
Sourcefn clone(&self) -> FlowGatePrincipal
fn clone(&self) -> FlowGatePrincipal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowGatePrincipal
impl Debug for FlowGatePrincipal
Sourceimpl<'de> Deserialize<'de> for FlowGatePrincipal
impl<'de> Deserialize<'de> for FlowGatePrincipal
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FlowGatePrincipal, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FlowGatePrincipal, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FlowGatePrincipal
impl PartialEq for FlowGatePrincipal
Sourcefn eq(&self, other: &FlowGatePrincipal) -> bool
fn eq(&self, other: &FlowGatePrincipal) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FlowGatePrincipal
impl Serialize for FlowGatePrincipal
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for FlowGatePrincipal
impl StructuralPartialEq for FlowGatePrincipal